# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_operation new_request send_request
#' @include ecr_service.R
NULL

#' Check the availability of multiple image layers in a specified registry
#' and repository
#'
#' Check the availability of multiple image layers in a specified registry
#' and repository.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_batch_check_layer_availability(registryId, repositoryName,
#'   layerDigests)
#'
#' @param registryId The AWS account ID associated with the registry that contains the image
#' layers to check. If you do not specify a registry, the default registry
#' is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository that is associated with the image layers to
#' check.
#' @param layerDigests &#91;required&#93; The digests of the image layers to check.
#'
#' @section Request syntax:
#' ```
#' svc$batch_check_layer_availability(
#'   registryId = "string",
#'   repositoryName = "string",
#'   layerDigests = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_batch_check_layer_availability
ecr_batch_check_layer_availability <- function(registryId = NULL, repositoryName, layerDigests) {
  op <- new_operation(
    name = "BatchCheckLayerAvailability",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$batch_check_layer_availability_input(registryId = registryId, repositoryName = repositoryName, layerDigests = layerDigests)
  output <- .ecr$batch_check_layer_availability_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$batch_check_layer_availability <- ecr_batch_check_layer_availability

#' Deletes a list of specified images within a specified repository
#'
#' Deletes a list of specified images within a specified repository. Images
#' are specified with either `imageTag` or `imageDigest`.
#' 
#' You can remove a tag from an image by specifying the image\'s tag in
#' your request. When you remove the last tag from an image, the image is
#' deleted from your repository.
#' 
#' You can completely delete an image (and all of its tags) by specifying
#' the image\'s digest in your request.
#'
#' @usage
#' ecr_batch_delete_image(registryId, repositoryName, imageIds)
#'
#' @param registryId The AWS account ID associated with the registry that contains the image
#' to delete. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The repository that contains the image to delete.
#' @param imageIds &#91;required&#93; A list of image ID references that correspond to images to delete. The
#' format of the `imageIds` reference is `imageTag=tag` or
#' `imageDigest=digest`.
#'
#' @section Request syntax:
#' ```
#' svc$batch_delete_image(
#'   registryId = "string",
#'   repositoryName = "string",
#'   imageIds = list(
#'     list(
#'       imageDigest = "string",
#'       imageTag = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example deletes images with the tags precise and trusty in a
#' # repository called ubuntu in the default registry for an account.
#' \donttest{svc$batch_delete_image(
#'   imageIds = list(
#'     list(
#'       imageTag = "precise"
#'     )
#'   ),
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_batch_delete_image
ecr_batch_delete_image <- function(registryId = NULL, repositoryName, imageIds) {
  op <- new_operation(
    name = "BatchDeleteImage",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$batch_delete_image_input(registryId = registryId, repositoryName = repositoryName, imageIds = imageIds)
  output <- .ecr$batch_delete_image_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$batch_delete_image <- ecr_batch_delete_image

#' Gets detailed information for specified images within a specified
#' repository
#'
#' Gets detailed information for specified images within a specified
#' repository. Images are specified with either `imageTag` or
#' `imageDigest`.
#'
#' @usage
#' ecr_batch_get_image(registryId, repositoryName, imageIds,
#'   acceptedMediaTypes)
#'
#' @param registryId The AWS account ID associated with the registry that contains the images
#' to describe. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The repository that contains the images to describe.
#' @param imageIds &#91;required&#93; A list of image ID references that correspond to images to describe. The
#' format of the `imageIds` reference is `imageTag=tag` or
#' `imageDigest=digest`.
#' @param acceptedMediaTypes The accepted media types for the request.
#' 
#' Valid values: `application/vnd.docker.distribution.manifest.v1+json` \\|
#' `application/vnd.docker.distribution.manifest.v2+json` \\|
#' `application/vnd.oci.image.manifest.v1+json`
#'
#' @section Request syntax:
#' ```
#' svc$batch_get_image(
#'   registryId = "string",
#'   repositoryName = "string",
#'   imageIds = list(
#'     list(
#'       imageDigest = "string",
#'       imageTag = "string"
#'     )
#'   ),
#'   acceptedMediaTypes = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example obtains information for an image with a specified image
#' # digest ID from the repository named ubuntu in the current account.
#' \donttest{svc$batch_get_image(
#'   imageIds = list(
#'     list(
#'       imageTag = "precise"
#'     )
#'   ),
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_batch_get_image
ecr_batch_get_image <- function(registryId = NULL, repositoryName, imageIds, acceptedMediaTypes = NULL) {
  op <- new_operation(
    name = "BatchGetImage",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$batch_get_image_input(registryId = registryId, repositoryName = repositoryName, imageIds = imageIds, acceptedMediaTypes = acceptedMediaTypes)
  output <- .ecr$batch_get_image_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$batch_get_image <- ecr_batch_get_image

#' Informs Amazon ECR that the image layer upload has completed for a
#' specified registry, repository name, and upload ID
#'
#' Informs Amazon ECR that the image layer upload has completed for a
#' specified registry, repository name, and upload ID. You can optionally
#' provide a `sha256` digest of the image layer for data validation
#' purposes.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_complete_layer_upload(registryId, repositoryName, uploadId,
#'   layerDigests)
#'
#' @param registryId The AWS account ID associated with the registry to which to upload
#' layers. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to associate with the image layer.
#' @param uploadId &#91;required&#93; The upload ID from a previous InitiateLayerUpload operation to associate
#' with the image layer.
#' @param layerDigests &#91;required&#93; The `sha256` digest of the image layer.
#'
#' @section Request syntax:
#' ```
#' svc$complete_layer_upload(
#'   registryId = "string",
#'   repositoryName = "string",
#'   uploadId = "string",
#'   layerDigests = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_complete_layer_upload
ecr_complete_layer_upload <- function(registryId = NULL, repositoryName, uploadId, layerDigests) {
  op <- new_operation(
    name = "CompleteLayerUpload",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$complete_layer_upload_input(registryId = registryId, repositoryName = repositoryName, uploadId = uploadId, layerDigests = layerDigests)
  output <- .ecr$complete_layer_upload_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$complete_layer_upload <- ecr_complete_layer_upload

#' Creates an image repository
#'
#' Creates an image repository.
#'
#' @usage
#' ecr_create_repository(repositoryName, tags)
#'
#' @param repositoryName &#91;required&#93; The name to use for the repository. The repository name may be specified
#' on its own (such as `nginx-web-app`) or it can be prepended with a
#' namespace to group the repository into a category (such as
#' `project-a/nginx-web-app`).
#' @param tags 
#'
#' @section Request syntax:
#' ```
#' svc$create_repository(
#'   repositoryName = "string",
#'   tags = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example creates a repository called nginx-web-app inside the
#' # project-a namespace in the default registry for an account.
#' \donttest{svc$create_repository(
#'   repositoryName = "project-a/nginx-web-app"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_create_repository
ecr_create_repository <- function(repositoryName, tags = NULL) {
  op <- new_operation(
    name = "CreateRepository",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$create_repository_input(repositoryName = repositoryName, tags = tags)
  output <- .ecr$create_repository_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$create_repository <- ecr_create_repository

#' Deletes the specified lifecycle policy
#'
#' Deletes the specified lifecycle policy.
#'
#' @usage
#' ecr_delete_lifecycle_policy(registryId, repositoryName)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository.
#'
#' @section Request syntax:
#' ```
#' svc$delete_lifecycle_policy(
#'   registryId = "string",
#'   repositoryName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_delete_lifecycle_policy
ecr_delete_lifecycle_policy <- function(registryId = NULL, repositoryName) {
  op <- new_operation(
    name = "DeleteLifecyclePolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$delete_lifecycle_policy_input(registryId = registryId, repositoryName = repositoryName)
  output <- .ecr$delete_lifecycle_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$delete_lifecycle_policy <- ecr_delete_lifecycle_policy

#' Deletes an existing image repository
#'
#' Deletes an existing image repository. If a repository contains images,
#' you must use the `force` option to delete it.
#'
#' @usage
#' ecr_delete_repository(registryId, repositoryName, force)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository to delete. If you do not specify a registry, the default
#' registry is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to delete.
#' @param force If a repository contains images, forces the deletion.
#'
#' @section Request syntax:
#' ```
#' svc$delete_repository(
#'   registryId = "string",
#'   repositoryName = "string",
#'   force = TRUE|FALSE
#' )
#' ```
#'
#' @examples
#' # This example force deletes a repository named ubuntu in the default
#' # registry for an account. The force parameter is required if the
#' # repository contains images.
#' \donttest{svc$delete_repository(
#'   force = TRUE,
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_delete_repository
ecr_delete_repository <- function(registryId = NULL, repositoryName, force = NULL) {
  op <- new_operation(
    name = "DeleteRepository",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$delete_repository_input(registryId = registryId, repositoryName = repositoryName, force = force)
  output <- .ecr$delete_repository_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$delete_repository <- ecr_delete_repository

#' Deletes the repository policy from a specified repository
#'
#' Deletes the repository policy from a specified repository.
#'
#' @usage
#' ecr_delete_repository_policy(registryId, repositoryName)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository policy to delete. If you do not specify a registry, the
#' default registry is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository that is associated with the repository policy
#' to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_repository_policy(
#'   registryId = "string",
#'   repositoryName = "string"
#' )
#' ```
#'
#' @examples
#' # This example deletes the policy associated with the repository named
#' # ubuntu in the current account.
#' \donttest{svc$delete_repository_policy(
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_delete_repository_policy
ecr_delete_repository_policy <- function(registryId = NULL, repositoryName) {
  op <- new_operation(
    name = "DeleteRepositoryPolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$delete_repository_policy_input(registryId = registryId, repositoryName = repositoryName)
  output <- .ecr$delete_repository_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$delete_repository_policy <- ecr_delete_repository_policy

#' Returns metadata about the images in a repository, including image size,
#' image tags, and creation date
#'
#' Returns metadata about the images in a repository, including image size,
#' image tags, and creation date.
#' 
#' Beginning with Docker version 1.9, the Docker client compresses image
#' layers before pushing them to a V2 Docker registry. The output of the
#' `docker images` command shows the uncompressed image size, so it may
#' return a larger image size than the image sizes returned by
#' DescribeImages.
#'
#' @usage
#' ecr_describe_images(registryId, repositoryName, imageIds, nextToken,
#'   maxResults, filter)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository in which to describe images. If you do not specify a
#' registry, the default registry is assumed.
#' @param repositoryName &#91;required&#93; A list of repositories to describe.
#' @param imageIds The list of image IDs for the requested repository.
#' @param nextToken The `nextToken` value returned from a previous paginated
#' `DescribeImages` request where `maxResults` was used and the results
#' exceeded the value of that parameter. Pagination continues from the end
#' of the previous results that returned the `nextToken` value. This value
#' is `null` when there are no more results to return. This option cannot
#' be used when you specify images with `imageIds`.
#' @param maxResults The maximum number of repository results returned by `DescribeImages` in
#' paginated output. When this parameter is used, `DescribeImages` only
#' returns `maxResults` results in a single page along with a `nextToken`
#' response element. The remaining results of the initial request can be
#' seen by sending another `DescribeImages` request with the returned
#' `nextToken` value. This value can be between 1 and 1000. If this
#' parameter is not used, then `DescribeImages` returns up to 100 results
#' and a `nextToken` value, if applicable. This option cannot be used when
#' you specify images with `imageIds`.
#' @param filter The filter key and value with which to filter your `DescribeImages`
#' results.
#'
#' @section Request syntax:
#' ```
#' svc$describe_images(
#'   registryId = "string",
#'   repositoryName = "string",
#'   imageIds = list(
#'     list(
#'       imageDigest = "string",
#'       imageTag = "string"
#'     )
#'   ),
#'   nextToken = "string",
#'   maxResults = 123,
#'   filter = list(
#'     tagStatus = "TAGGED"|"UNTAGGED"|"ANY"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_describe_images
ecr_describe_images <- function(registryId = NULL, repositoryName, imageIds = NULL, nextToken = NULL, maxResults = NULL, filter = NULL) {
  op <- new_operation(
    name = "DescribeImages",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$describe_images_input(registryId = registryId, repositoryName = repositoryName, imageIds = imageIds, nextToken = nextToken, maxResults = maxResults, filter = filter)
  output <- .ecr$describe_images_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$describe_images <- ecr_describe_images

#' Describes image repositories in a registry
#'
#' Describes image repositories in a registry.
#'
#' @usage
#' ecr_describe_repositories(registryId, repositoryNames, nextToken,
#'   maxResults)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repositories to be described. If you do not specify a registry, the
#' default registry is assumed.
#' @param repositoryNames A list of repositories to describe. If this parameter is omitted, then
#' all repositories in a registry are described.
#' @param nextToken The `nextToken` value returned from a previous paginated
#' `DescribeRepositories` request where `maxResults` was used and the
#' results exceeded the value of that parameter. Pagination continues from
#' the end of the previous results that returned the `nextToken` value.
#' This value is `null` when there are no more results to return. This
#' option cannot be used when you specify repositories with
#' `repositoryNames`.
#' 
#' This token should be treated as an opaque identifier that is only used
#' to retrieve the next items in a list and not for other programmatic
#' purposes.
#' @param maxResults The maximum number of repository results returned by
#' `DescribeRepositories` in paginated output. When this parameter is used,
#' `DescribeRepositories` only returns `maxResults` results in a single
#' page along with a `nextToken` response element. The remaining results of
#' the initial request can be seen by sending another
#' `DescribeRepositories` request with the returned `nextToken` value. This
#' value can be between 1 and 1000. If this parameter is not used, then
#' `DescribeRepositories` returns up to 100 results and a `nextToken`
#' value, if applicable. This option cannot be used when you specify
#' repositories with `repositoryNames`.
#'
#' @section Request syntax:
#' ```
#' svc$describe_repositories(
#'   registryId = "string",
#'   repositoryNames = list(
#'     "string"
#'   ),
#'   nextToken = "string",
#'   maxResults = 123
#' )
#' ```
#'
#' @examples
#' # The following example obtains a list and description of all repositories
#' # in the default registry to which the current user has access.
#' \donttest{svc$describe_repositories()}
#'
#' @keywords internal
#'
#' @rdname ecr_describe_repositories
ecr_describe_repositories <- function(registryId = NULL, repositoryNames = NULL, nextToken = NULL, maxResults = NULL) {
  op <- new_operation(
    name = "DescribeRepositories",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$describe_repositories_input(registryId = registryId, repositoryNames = repositoryNames, nextToken = nextToken, maxResults = maxResults)
  output <- .ecr$describe_repositories_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$describe_repositories <- ecr_describe_repositories

#' Retrieves a token that is valid for a specified registry for 12 hours
#'
#' Retrieves a token that is valid for a specified registry for 12 hours.
#' This command allows you to use the `docker` CLI to push and pull images
#' with Amazon ECR. If you do not specify a registry, the default registry
#' is assumed.
#' 
#' The `authorizationToken` returned for each registry specified is a
#' base64 encoded string that can be decoded and used in a `docker login`
#' command to authenticate to a registry. The AWS CLI offers an
#' `aws ecr get-login` command that simplifies the login process.
#'
#' @usage
#' ecr_get_authorization_token(registryIds)
#'
#' @param registryIds A list of AWS account IDs that are associated with the registries for
#' which to get authorization tokens. If you do not specify a registry, the
#' default registry is assumed.
#'
#' @section Request syntax:
#' ```
#' svc$get_authorization_token(
#'   registryIds = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example gets an authorization token for your default registry.
#' \donttest{svc$get_authorization_token()}
#'
#' @keywords internal
#'
#' @rdname ecr_get_authorization_token
ecr_get_authorization_token <- function(registryIds = NULL) {
  op <- new_operation(
    name = "GetAuthorizationToken",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$get_authorization_token_input(registryIds = registryIds)
  output <- .ecr$get_authorization_token_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$get_authorization_token <- ecr_get_authorization_token

#' Retrieves the pre-signed Amazon S3 download URL corresponding to an
#' image layer
#'
#' Retrieves the pre-signed Amazon S3 download URL corresponding to an
#' image layer. You can only get URLs for image layers that are referenced
#' in an image.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_get_download_url_for_layer(registryId, repositoryName, layerDigest)
#'
#' @param registryId The AWS account ID associated with the registry that contains the image
#' layer to download. If you do not specify a registry, the default
#' registry is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository that is associated with the image layer to
#' download.
#' @param layerDigest &#91;required&#93; The digest of the image layer to download.
#'
#' @section Request syntax:
#' ```
#' svc$get_download_url_for_layer(
#'   registryId = "string",
#'   repositoryName = "string",
#'   layerDigest = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_get_download_url_for_layer
ecr_get_download_url_for_layer <- function(registryId = NULL, repositoryName, layerDigest) {
  op <- new_operation(
    name = "GetDownloadUrlForLayer",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$get_download_url_for_layer_input(registryId = registryId, repositoryName = repositoryName, layerDigest = layerDigest)
  output <- .ecr$get_download_url_for_layer_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$get_download_url_for_layer <- ecr_get_download_url_for_layer

#' Retrieves the specified lifecycle policy
#'
#' Retrieves the specified lifecycle policy.
#'
#' @usage
#' ecr_get_lifecycle_policy(registryId, repositoryName)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository.
#'
#' @section Request syntax:
#' ```
#' svc$get_lifecycle_policy(
#'   registryId = "string",
#'   repositoryName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_get_lifecycle_policy
ecr_get_lifecycle_policy <- function(registryId = NULL, repositoryName) {
  op <- new_operation(
    name = "GetLifecyclePolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$get_lifecycle_policy_input(registryId = registryId, repositoryName = repositoryName)
  output <- .ecr$get_lifecycle_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$get_lifecycle_policy <- ecr_get_lifecycle_policy

#' Retrieves the results of the specified lifecycle policy preview request
#'
#' Retrieves the results of the specified lifecycle policy preview request.
#'
#' @usage
#' ecr_get_lifecycle_policy_preview(registryId, repositoryName, imageIds,
#'   nextToken, maxResults, filter)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository.
#' @param imageIds The list of imageIDs to be included.
#' @param nextToken The `nextToken` value returned from a previous paginatedâ€¨
#' `GetLifecyclePolicyPreviewRequest` request where `maxResults` was used
#' and theâ€¨ results exceeded the value of that parameter. Pagination
#' continues from the end of theâ€¨ previous results that returned the
#' `nextToken` value. This value isâ€¨ `null` when there are no more results
#' to return. This option cannot be used when you specify images with
#' `imageIds`.
#' @param maxResults The maximum number of repository results returned by
#' `GetLifecyclePolicyPreviewRequest` inâ€¨ paginated output. When this
#' parameter is used, `GetLifecyclePolicyPreviewRequest` only returnsâ€¨
#' `maxResults` results in a single page along with a `nextToken`â€¨ response
#' element. The remaining results of the initial request can be seen by
#' sendingâ€¨ another `GetLifecyclePolicyPreviewRequest` request with the
#' returned `nextToken`â€¨ value. This value can be between 1 and 1000. If
#' thisâ€¨ parameter is not used, then `GetLifecyclePolicyPreviewRequest`
#' returns up toâ€¨ 100 results and a `nextToken` value, ifâ€¨ applicable. This
#' option cannot be used when you specify images with `imageIds`.
#' @param filter An optional parameter that filters results based on image tag status and
#' all tags, if tagged.
#'
#' @section Request syntax:
#' ```
#' svc$get_lifecycle_policy_preview(
#'   registryId = "string",
#'   repositoryName = "string",
#'   imageIds = list(
#'     list(
#'       imageDigest = "string",
#'       imageTag = "string"
#'     )
#'   ),
#'   nextToken = "string",
#'   maxResults = 123,
#'   filter = list(
#'     tagStatus = "TAGGED"|"UNTAGGED"|"ANY"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_get_lifecycle_policy_preview
ecr_get_lifecycle_policy_preview <- function(registryId = NULL, repositoryName, imageIds = NULL, nextToken = NULL, maxResults = NULL, filter = NULL) {
  op <- new_operation(
    name = "GetLifecyclePolicyPreview",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$get_lifecycle_policy_preview_input(registryId = registryId, repositoryName = repositoryName, imageIds = imageIds, nextToken = nextToken, maxResults = maxResults, filter = filter)
  output <- .ecr$get_lifecycle_policy_preview_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$get_lifecycle_policy_preview <- ecr_get_lifecycle_policy_preview

#' Retrieves the repository policy for a specified repository
#'
#' Retrieves the repository policy for a specified repository.
#'
#' @usage
#' ecr_get_repository_policy(registryId, repositoryName)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository with the policy to retrieve.
#'
#' @section Request syntax:
#' ```
#' svc$get_repository_policy(
#'   registryId = "string",
#'   repositoryName = "string"
#' )
#' ```
#'
#' @examples
#' # This example obtains the repository policy for the repository named
#' # ubuntu.
#' \donttest{svc$get_repository_policy(
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_get_repository_policy
ecr_get_repository_policy <- function(registryId = NULL, repositoryName) {
  op <- new_operation(
    name = "GetRepositoryPolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$get_repository_policy_input(registryId = registryId, repositoryName = repositoryName)
  output <- .ecr$get_repository_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$get_repository_policy <- ecr_get_repository_policy

#' Notify Amazon ECR that you intend to upload an image layer
#'
#' Notify Amazon ECR that you intend to upload an image layer.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_initiate_layer_upload(registryId, repositoryName)
#'
#' @param registryId The AWS account ID associated with the registry to which you intend to
#' upload layers. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to which you intend to upload layers.
#'
#' @section Request syntax:
#' ```
#' svc$initiate_layer_upload(
#'   registryId = "string",
#'   repositoryName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_initiate_layer_upload
ecr_initiate_layer_upload <- function(registryId = NULL, repositoryName) {
  op <- new_operation(
    name = "InitiateLayerUpload",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$initiate_layer_upload_input(registryId = registryId, repositoryName = repositoryName)
  output <- .ecr$initiate_layer_upload_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$initiate_layer_upload <- ecr_initiate_layer_upload

#' Lists all the image IDs for a given repository
#'
#' Lists all the image IDs for a given repository.
#' 
#' You can filter images based on whether or not they are tagged by setting
#' the `tagStatus` parameter to `TAGGED` or `UNTAGGED`. For example, you
#' can filter your results to return only `UNTAGGED` images and then pipe
#' that result to a BatchDeleteImage operation to delete them. Or, you can
#' filter your results to return only `TAGGED` images to list all of the
#' tags in your repository.
#'
#' @usage
#' ecr_list_images(registryId, repositoryName, nextToken, maxResults,
#'   filter)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository in which to list images. If you do not specify a registry,
#' the default registry is assumed.
#' @param repositoryName &#91;required&#93; The repository with image IDs to be listed.
#' @param nextToken The `nextToken` value returned from a previous paginated `ListImages`
#' request where `maxResults` was used and the results exceeded the value
#' of that parameter. Pagination continues from the end of the previous
#' results that returned the `nextToken` value. This value is `null` when
#' there are no more results to return.
#' 
#' This token should be treated as an opaque identifier that is only used
#' to retrieve the next items in a list and not for other programmatic
#' purposes.
#' @param maxResults The maximum number of image results returned by `ListImages` in
#' paginated output. When this parameter is used, `ListImages` only returns
#' `maxResults` results in a single page along with a `nextToken` response
#' element. The remaining results of the initial request can be seen by
#' sending another `ListImages` request with the returned `nextToken`
#' value. This value can be between 1 and 1000. If this parameter is not
#' used, then `ListImages` returns up to 100 results and a `nextToken`
#' value, if applicable.
#' @param filter The filter key and value with which to filter your `ListImages` results.
#'
#' @section Request syntax:
#' ```
#' svc$list_images(
#'   registryId = "string",
#'   repositoryName = "string",
#'   nextToken = "string",
#'   maxResults = 123,
#'   filter = list(
#'     tagStatus = "TAGGED"|"UNTAGGED"|"ANY"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example lists all of the images in the repository named ubuntu in
#' # the default registry in the current account.
#' \donttest{svc$list_images(
#'   repositoryName = "ubuntu"
#' )}
#'
#' @keywords internal
#'
#' @rdname ecr_list_images
ecr_list_images <- function(registryId = NULL, repositoryName, nextToken = NULL, maxResults = NULL, filter = NULL) {
  op <- new_operation(
    name = "ListImages",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$list_images_input(registryId = registryId, repositoryName = repositoryName, nextToken = nextToken, maxResults = maxResults, filter = filter)
  output <- .ecr$list_images_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$list_images <- ecr_list_images

#' List the tags for an Amazon ECR resource
#'
#' List the tags for an Amazon ECR resource.
#'
#' @usage
#' ecr_list_tags_for_resource(resourceArn)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) that identifies the resource for which to
#' list the tags. Currently, the only supported resource is an Amazon ECR
#' repository.
#'
#' @section Request syntax:
#' ```
#' svc$list_tags_for_resource(
#'   resourceArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_list_tags_for_resource
ecr_list_tags_for_resource <- function(resourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$list_tags_for_resource_input(resourceArn = resourceArn)
  output <- .ecr$list_tags_for_resource_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$list_tags_for_resource <- ecr_list_tags_for_resource

#' Creates or updates the image manifest and tags associated with an image
#'
#' Creates or updates the image manifest and tags associated with an image.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_put_image(registryId, repositoryName, imageManifest, imageTag)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository in which to put the image. If you do not specify a registry,
#' the default registry is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository in which to put the image.
#' @param imageManifest &#91;required&#93; The image manifest corresponding to the image to be uploaded.
#' @param imageTag The tag to associate with the image. This parameter is required for
#' images that use the Docker Image Manifest V2 Schema 2 or OCI formats.
#'
#' @section Request syntax:
#' ```
#' svc$put_image(
#'   registryId = "string",
#'   repositoryName = "string",
#'   imageManifest = "string",
#'   imageTag = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_put_image
ecr_put_image <- function(registryId = NULL, repositoryName, imageManifest, imageTag = NULL) {
  op <- new_operation(
    name = "PutImage",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$put_image_input(registryId = registryId, repositoryName = repositoryName, imageManifest = imageManifest, imageTag = imageTag)
  output <- .ecr$put_image_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$put_image <- ecr_put_image

#' Creates or updates a lifecycle policy
#'
#' Creates or updates a lifecycle policy. For information about lifecycle
#' policy syntax, see [Lifecycle Policy
#' Template](http://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html).
#'
#' @usage
#' ecr_put_lifecycle_policy(registryId, repositoryName,
#'   lifecyclePolicyText)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you doâ€¨ not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to receive the policy.
#' @param lifecyclePolicyText &#91;required&#93; The JSON repository policy text to apply to the repository.
#'
#' @section Request syntax:
#' ```
#' svc$put_lifecycle_policy(
#'   registryId = "string",
#'   repositoryName = "string",
#'   lifecyclePolicyText = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_put_lifecycle_policy
ecr_put_lifecycle_policy <- function(registryId = NULL, repositoryName, lifecyclePolicyText) {
  op <- new_operation(
    name = "PutLifecyclePolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$put_lifecycle_policy_input(registryId = registryId, repositoryName = repositoryName, lifecyclePolicyText = lifecyclePolicyText)
  output <- .ecr$put_lifecycle_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$put_lifecycle_policy <- ecr_put_lifecycle_policy

#' Applies a repository policy on a specified repository to control access
#' permissions
#'
#' Applies a repository policy on a specified repository to control access
#' permissions.
#'
#' @usage
#' ecr_set_repository_policy(registryId, repositoryName, policyText, force)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to receive the policy.
#' @param policyText &#91;required&#93; The JSON repository policy text to apply to the repository.
#' @param force If the policy you are attempting to set on a repository policy would
#' prevent you from setting another policy in the future, you must force
#' the SetRepositoryPolicy operation. This is intended to prevent
#' accidental repository lock outs.
#'
#' @section Request syntax:
#' ```
#' svc$set_repository_policy(
#'   registryId = "string",
#'   repositoryName = "string",
#'   policyText = "string",
#'   force = TRUE|FALSE
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_set_repository_policy
ecr_set_repository_policy <- function(registryId = NULL, repositoryName, policyText, force = NULL) {
  op <- new_operation(
    name = "SetRepositoryPolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$set_repository_policy_input(registryId = registryId, repositoryName = repositoryName, policyText = policyText, force = force)
  output <- .ecr$set_repository_policy_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$set_repository_policy <- ecr_set_repository_policy

#' Starts a preview of the specified lifecycle policy
#'
#' Starts a preview of the specified lifecycle policy. This allows you to
#' see the results before creating the lifecycle policy.
#'
#' @usage
#' ecr_start_lifecycle_policy_preview(registryId, repositoryName,
#'   lifecyclePolicyText)
#'
#' @param registryId The AWS account ID associated with the registry that contains the
#' repository. If you do not specify a registry, the default registry is
#' assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to be evaluated.
#' @param lifecyclePolicyText The policy to be evaluated against. If you do not specify a policy, the
#' current policy for the repository is used.
#'
#' @section Request syntax:
#' ```
#' svc$start_lifecycle_policy_preview(
#'   registryId = "string",
#'   repositoryName = "string",
#'   lifecyclePolicyText = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_start_lifecycle_policy_preview
ecr_start_lifecycle_policy_preview <- function(registryId = NULL, repositoryName, lifecyclePolicyText = NULL) {
  op <- new_operation(
    name = "StartLifecyclePolicyPreview",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$start_lifecycle_policy_preview_input(registryId = registryId, repositoryName = repositoryName, lifecyclePolicyText = lifecyclePolicyText)
  output <- .ecr$start_lifecycle_policy_preview_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$start_lifecycle_policy_preview <- ecr_start_lifecycle_policy_preview

#' Adds specified tags to a resource with the specified ARN
#'
#' Adds specified tags to a resource with the specified ARN. Existing tags
#' on a resource are not changed if they are not specified in the request
#' parameters.
#'
#' @usage
#' ecr_tag_resource(resourceArn, tags)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the the resource to which to add tags.
#' Currently, the only supported resource is an Amazon ECR repository.
#' @param tags &#91;required&#93; The tags to add to the resource. A tag is an array of key-value pairs.
#' Tag keys can have a maximum character length of 128 characters, and tag
#' values can have a maximum length of 256 characters.
#'
#' @section Request syntax:
#' ```
#' svc$tag_resource(
#'   resourceArn = "string",
#'   tags = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_tag_resource
ecr_tag_resource <- function(resourceArn, tags) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$tag_resource_input(resourceArn = resourceArn, tags = tags)
  output <- .ecr$tag_resource_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$tag_resource <- ecr_tag_resource

#' Deletes specified tags from a resource
#'
#' Deletes specified tags from a resource.
#'
#' @usage
#' ecr_untag_resource(resourceArn, tagKeys)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource from which to remove
#' tags. Currently, the only supported resource is an Amazon ECR
#' repository.
#' @param tagKeys &#91;required&#93; The keys of the tags to be removed.
#'
#' @section Request syntax:
#' ```
#' svc$untag_resource(
#'   resourceArn = "string",
#'   tagKeys = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_untag_resource
ecr_untag_resource <- function(resourceArn, tagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$untag_resource_input(resourceArn = resourceArn, tagKeys = tagKeys)
  output <- .ecr$untag_resource_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$untag_resource <- ecr_untag_resource

#' Uploads an image layer part to Amazon ECR
#'
#' Uploads an image layer part to Amazon ECR.
#' 
#' This operation is used by the Amazon ECR proxy, and it is not intended
#' for general use by customers for pulling and pushing images. In most
#' cases, you should use the `docker` CLI to pull, tag, and push images.
#'
#' @usage
#' ecr_upload_layer_part(registryId, repositoryName, uploadId,
#'   partFirstByte, partLastByte, layerPartBlob)
#'
#' @param registryId The AWS account ID associated with the registry to which you are
#' uploading layer parts. If you do not specify a registry, the default
#' registry is assumed.
#' @param repositoryName &#91;required&#93; The name of the repository to which you are uploading layer parts.
#' @param uploadId &#91;required&#93; The upload ID from a previous InitiateLayerUpload operation to associate
#' with the layer part upload.
#' @param partFirstByte &#91;required&#93; The integer value of the first byte of the layer part.
#' @param partLastByte &#91;required&#93; The integer value of the last byte of the layer part.
#' @param layerPartBlob &#91;required&#93; The base64-encoded layer part payload.
#'
#' @section Request syntax:
#' ```
#' svc$upload_layer_part(
#'   registryId = "string",
#'   repositoryName = "string",
#'   uploadId = "string",
#'   partFirstByte = 123,
#'   partLastByte = 123,
#'   layerPartBlob = raw
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname ecr_upload_layer_part
ecr_upload_layer_part <- function(registryId = NULL, repositoryName, uploadId, partFirstByte, partLastByte, layerPartBlob) {
  op <- new_operation(
    name = "UploadLayerPart",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .ecr$upload_layer_part_input(registryId = registryId, repositoryName = repositoryName, uploadId = uploadId, partFirstByte = partFirstByte, partLastByte = partLastByte, layerPartBlob = layerPartBlob)
  output <- .ecr$upload_layer_part_output()
  svc <- .ecr$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.ecr$operations$upload_layer_part <- ecr_upload_layer_part
